@@ -108,7 +108,7 @@ impl SafeAppClient {
         } else {
             debug!("Storing {} bytes of data", bytes.len());
             let client = self.get_safe_client()?;
-            let address = client.upload(bytes, Scope::Public).await?;
+            let address = client.upload_and_verify(bytes, Scope::Public).await?;
             *address.name()
         };
         Ok(xorname)
